==> ui-18.0.4.tgz: package/components/table/TableTh.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React from 'react';
import { CaretDownOutlined, CaretUpOutlined } from '@react-devui/icons';
import { checkNodeExist, getClassName } from '@react-devui/utils';
import { useDValue } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DCell } from './Cell';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DTable.Th' });
export function DTableTh(props) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dWidth, dSort, dActions = [], dFixed, dAlign = 'left', dEllipsis = false } = _a, restProps = __rest(_a, ["children", "dWidth", "dSort", "dActions", "dFixed", "dAlign", "dEllipsis"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const [sort, changeSort] = useDValue(null, dSort === null || dSort === void 0 ? void 0 : dSort.active, dSort === null || dSort === void 0 ? void 0 : dSort.onSort);
    return (_jsxs(DCell, Object.assign({}, restProps, { className: getClassName(restProps.className, {
            [`${dPrefix}table__cell--th-empty`]: !checkNodeExist(children),
            [`${dPrefix}table__cell--th-sort`]: dSort,
        }), "aria-sort": sort === 'ascend' ? 'ascending' : sort === 'descend' ? 'descending' : undefined, onClick: () => {
            var _a;
            if (dSort) {
                const sortOptions = (_a = dSort.options) !== null && _a !== void 0 ? _a : [null, 'ascend', 'descend'];
                changeSort((draft) => sortOptions[(sortOptions.findIndex((order) => order === draft) + 1) % sortOptions.length]);
            }
        }, dTag: "th", dWidth: dWidth, dFixed: dFixed, dAlign: dAlign, dEllipsis: dEllipsis }, { children: [_jsx("div", Object.assign({ className: `${dPrefix}table__cell-text` }, { children: children })), (dSort || dActions.length > 0) && (_jsxs("div", Object.assign({ className: `${dPrefix}table__th-actions`, "aria-hidden": true }, { children: [dSort && (_jsxs("button", Object.assign({ className: getClassName(`${dPrefix}table__th-action`, `${dPrefix}table__th-action--sort`) }, { children: [(isUndefined(dSort.options) || dSort.options.includes('ascend')) && (_jsx(CaretUpOutlined, { className: getClassName(`${dPrefix}table__th-sort-icon`, {
                                    'is-active': sort === 'ascend',
                                }) })), (isUndefined(dSort.options) || dSort.options.includes('descend')) && (_jsx(CaretDownOutlined, { className: getClassName(`${dPrefix}table__th-sort-icon`, {
                                    'is-active': sort === 'descend',
                                }) }))] }))), React.Children.map(dActions, (action) => React.cloneElement(action, {
                        className: getClassName(action.props.className, `${dPrefix}table__th-action`),
                        onClick: (e) => {
                            var _a, _b;
                            (_b = (_a = action.props).onClick) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                            e.stopPropagation();
                        },
                    }))] })))] })));
}

==> ui-18.4.0.tgz: package/components/table/TableTh.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React from 'react';
import { CaretDownOutlined, CaretUpOutlined } from '@react-devui/icons';
import { checkNodeExist, getClassName } from '@react-devui/utils';
import { useDValue } from '../../hooks';
import { registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig } from '../root';
import { DCell } from './Cell';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DTable.Th' });
export function DTableTh(props) {
    const _a = useComponentConfig(COMPONENT_NAME, props), { children, dWidth, dSort, dActions = [], dFixed, dAlign = 'left', dEllipsis = false, dNowrap = true } = _a, restProps = __rest(_a, ["children", "dWidth", "dSort", "dActions", "dFixed", "dAlign", "dEllipsis", "dNowrap"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const [sort, changeSort] = useDValue(null, dSort === null || dSort === void 0 ? void 0 : dSort.active, dSort === null || dSort === void 0 ? void 0 : dSort.onSort);
    return (_jsxs(DCell, Object.assign({}, restProps, { className: getClassName(restProps.className, {
            [`${dPrefix}table__cell--th-empty`]: !checkNodeExist(children),
            [`${dPrefix}table__cell--th-sort`]: dSort,
        }), "aria-sort": sort === 'ascend' ? 'ascending' : sort === 'descend' ? 'descending' : undefined, onClick: () => {
            var _a;
            if (dSort) {
                const sortOptions = (_a = dSort.options) !== null && _a !== void 0 ? _a : [null, 'ascend', 'descend'];
                changeSort((draft) => sortOptions[(sortOptions.findIndex((order) => order === draft) + 1) % sortOptions.length]);
            }
        }, dTag: "th", dWidth: dWidth, dFixed: dFixed, dAlign: dAlign, dEllipsis: dEllipsis, dNowrap: dNowrap }, { children: [_jsx("div", Object.assign({ className: `${dPrefix}table__cell-text` }, { children: children })), (dSort || dActions.length > 0) && (_jsxs("div", Object.assign({ className: `${dPrefix}table__th-actions`, "aria-hidden": true }, { children: [dSort && (_jsxs("button", Object.assign({ className: getClassName(`${dPrefix}table__th-action`, `${dPrefix}table__th-action--sort`) }, { children: [(isUndefined(dSort.options) || dSort.options.includes('ascend')) && (_jsx(CaretUpOutlined, { className: getClassName(`${dPrefix}table__th-sort-icon`, {
                                    'is-active': sort === 'ascend',
                                }) })), (isUndefined(dSort.options) || dSort.options.includes('descend')) && (_jsx(CaretDownOutlined, { className: getClassName(`${dPrefix}table__th-sort-icon`, {
                                    'is-active': sort === 'descend',
                                }) }))] }))), React.Children.map(dActions, (action) => action)] })))] })));
}
